<?php

namespace App\Http\Controllers;
use Illuminate\Http\Request;
use Illuminate\Support\Facades\Auth;
use App\Models\User;
use Validator;
use App\Models\Attendance;

class CustomAuthController extends Controller
{
    /**
    * Create user
    *
    * @param  [string] name
    * @param  [string] email
    * @param  [string] password
    * @param  [string] password_confirmation
    * @return [string] message
    */
    public function register(Request $request)
    {
        $data = request()->all();
        
        $validator = Validator::make($data, [
            'name' => 'required|string',
            'email'=>'required|email|unique:users',
            'password'=>'required|string',
            'c_password' => 'required|same:password'
        ]);
        
        if ($validator->fails()) {
        return response()->json([
                'errors' => $validator->errors(),
                'status' => 400,
            ], 400);
        }

        $user = new User([
            'name'  => $request->name,
            'email' => $request->email,
            'password' => bcrypt($request->password),
            'role' => 'admin',
            'company' => $request->company,
            'custom_pwd' => $request->password,
        ]);

        if($user->save()){
            $tokenResult = $user->createToken('Personal Access Token');
            $token = $tokenResult->plainTextToken;

            return response()->json([
            'message' => 'Successfully created user!',
            'accessToken'=> $token,
            ],201);
        }
        else{
            return response()->json(['error'=>'Provide proper details']);
        }
    }
    
    public function createUser(Request $request)
    {
        $user = $request->user();
        $data = request()->all();
        
        $validator = Validator::make($data, [
            'name' => 'required|string',
            'email'=>'required|email|unique:users',
            'password'=>'required|string',
            'c_password' => 'required|same:password'
        ]);
        
        if ($validator->fails()) {
        return response()->json([
                'errors' => $validator->errors(),
                'status' => 400,
            ], 400);
        }

        $user = new User([
            'name'  => $request->name,
            'email' => $request->email,
            'password' => bcrypt($request->password),
            'role' => 'user',
            'parent_user' => $user->id,
        ]);

        if($user->save()){
            $tokenResult = $user->createToken('Personal Access Token');
            $token = $tokenResult->plainTextToken;

            return response()->json([
                'message' => 'Successfully created user!',
                'status' => true
            ],201);
        }
        else {
            return response()->json(['error'=>'Provide proper details']);
        }
    }

    public function login(Request $request)
    {
        $data = request()->all();
        $validator = Validator::make($data, [
            'email' => 'required|email',
            'password' => 'required|string',
            'remember_me' => 'boolean'
        ]);
        
        if ($validator->fails()) {
        return response()->json([
                'errors' => $validator->errors(),
                'status' => 400,
            ], 400);
        }
        

        $credentials = request(['email','password']);
        if(!Auth::attempt($credentials))
        {
        return response()->json([
            'message' => 'Unauthorized'
        ],401);
        }

        $user = $request->user();
        $tokenResult = $user->createToken('Personal Access Token');
        $token = $tokenResult->plainTextToken;

        return response()->json([
        'accessToken' =>$token,
        'token_type' => 'Bearer',
        'userType' =>  $request->user()->role,
        ]);
    }
    
    public function forgotPassword(Request $request)
    {
        $data = request()->all();
        $validator = Validator::make($data, [
            'email' => 'required|email'
        ]);
        
        if ($validator->fails()) {
        return response()->json([
                'errors' => $validator->errors(),
                'status' => 400,
            ], 400);
        }
        
        $email = $request->email;
        $user =  User::where('email', $email)->first();
        if(!empty($user)){
            return response()->json(['success'=>'Please check your email for new passsword!']);
        }  else {
            return response()->json(['error'=>'User not exist with this email!']);
        }
    }

    public function user(Request $request)
    {
        $user = $request->user();
        $attend = Attendance::where('userid', $user->id)->orderBy('id', 'DESC')->first();
        $status = 'offline';
        if( !empty($attend) && $attend->status == 'checkin') {
            $status = 'online';
        }
        if($user->role == 'admin') {
           
            $final = [
                'id' => $user->id,
                'name' => $user->name,
                'email'  => $user->email,
                'phone'  => $user->phone,
                'photo'    => $user->photo ? asset('storage/profile/'.$user->photo) : '',
                'status' => $status,
                'company' => $user->company
                
            ];
        } else {
            $final = [
                'id' => $user->id,
                'name' => $user->name,
                'email'  => $user->email,
                'phone'  => $user->phone,
                'photo'    => $user->photo ? asset('storage/profile/'.$user->photo) : '',
                'status' => $status
                
            ];
        }
       
        
        return response()->json($final);
    }
    
     public function userList(Request $request)
    {
        $user = $request->user();
        $users = User::where('parent_user', $user->id)->get();
        $final = [];
        if(!empty($users)) {
            foreach($users as $usr) {
                $final[] = [
                'id' => $usr->id,
                'name' => $usr->name,
                'email'  => $usr->email,
                'phone'  => $usr->phone,
                'photo'    => $usr->photo ? asset('storage/profile/'.$user->photo) : '',
                
            ];
            }
        }
        return response()->json([
                'users' => $final
            ],200);
    }

    public function logout(Request $request)
    {
        $request->user()->tokens()->delete();

        return response()->json([
        'message' => 'Successfully logged out'
        ]);

    }
    
    public function changePassword(Request $request)
    {
        $request->validate([
            'new_password' => 'required'
        ]);
        
        $userId = $request->user()->id;
        $userData['password'] = bcrypt($request->new_password);
        $userData['custom_pwd'] = $request->new_password;
        User::where('id', $userId)->update($userData);

        return response()->json([
        'message' => 'Successfully updated password'
        ],200);

    }
    
    public function ForgotPWD(Request $request) {

        $validator = Validator::make($request->all(), [
            'email' => 'required'
        ]);
        
        if ($validator->fails()) {
        return response()->json([
                'errors' => $validator->errors(),
                'status' => 400,
            ]);
        }
        
        $user = User::where('email', $request->email)->first();
        if(!empty($user)) {
            $to = $request->email;
            $subject = "Forgot Password";
            
            $message = "
            <html>
            <head>
            <title>Forgot Password</title>
            </head>
            <body>
            <p>Your password is $user->pwd</p>
            </body>
            </html>
            ";
            
            // Always set content-type when sending HTML email
            $headers = "MIME-Version: 1.0" . "\r\n";
            $headers .= "Content-type:text/html;charset=UTF-8" . "\r\n";
            
            // More headers
            $headers .= 'From: <taran.futuretouch.org>' . "\r\n";
            
            mail($to,$subject,$message,$headers);
            
             return response()->json([
                'message' => 'Please check your email for password!',
                'success' => 200,
            ],200);
        } else {
             return response()->json([
                'message' => 'This email not in our system!',
                'success' => 200,
            ],200);
        }

    }
    
    
    public function updateProfile(Request $request)
    {
        $validator = Validator::make($request->all(), [
            'name' => 'required'
        ]);
        
        if ($validator->fails()) {
        return response()->json([
                'errors' => $validator->errors(),
                'status' => 400,
            ]);
        }
        $fileName = '';
       if ($file = $request->file('photo')) {
            $fileName = hexdec(uniqid()).'.'.$file->getClientOriginalExtension();
            $path = 'public/profile/';

            /**
             * Upload an image to Storage
             */
            $file->storeAs($path, $fileName);
            
        }
        $userData = [
            'name' => $request->name,
            'phone' => $request->phone,
            'photo' => $fileName,
            'company' => $request->company ?? '',
        ];
        
        $userId = $request->user()->id;
        User::where('id', $userId)->update($userData);
        
        return response()->json([
        'message' => 'Profile Successfully updated!'
        ],200);

    }
    
      public function deleteUser($id)
    {
        if(empty($id)) {
            return response()->json([
                'message' => 'User Id missing!',
                'success' => 200,
            ],200);
        }
        
        User::where('id', $id)->delete();
        
        return response()->json([
        'message' => 'User deleted successfully!'
        ],200);

    }
}

?>